//
// Copyright (c) 2022, MindFusion LLC - Bulgaria.
//

using System;
using System.Drawing;
using System.Windows.Forms;


namespace MindFusion.Diagramming.WinForms.Samples.CS.LayeredLayout
{
    public partial class MainForm : Form
    {
        public MainForm()
        {
            InitializeComponent();

            MindFusion.Drawing.LinearGradientBrush brush = new MindFusion.Drawing.LinearGradientBrush(Color.Black, Color.White);
            brush.InterpolationColors = new System.Drawing.Drawing2D.ColorBlend();
            brush.InterpolationColors.Positions = new float[] { 0, 0.37F, 0.86F, 1 };
            brush.InterpolationColors.Colors = new Color[] {
                Color.FromArgb(255,111,127,159),
                 Color.FromArgb(255,207,222,255), 
                 Color.FromArgb(255,111,127,159),
                 Color.FromArgb(255,47,63,111), 
            };
            diagram1.ShapeNodeStyle.Brush = brush;
            diagram1.ShapeNodeStyle.Stroke = new MindFusion.Drawing.SolidBrush(Color.FromArgb(97, 106, 127));
            diagram1.DiagramLinkStyle.Stroke = new MindFusion.Drawing.SolidBrush(Color.FromArgb(97, 106, 127)); 
        }

        private void button1_Click(object sender, EventArgs e)
        {
            RandomGraph();
            Arrange();
        }

        private void Arrange()
        {
            MindFusion.Diagramming.Layout.LayeredLayout layout = new MindFusion.Diagramming.Layout.LayeredLayout();
            layout.Anchoring = Anchoring.Reassign;
            layout.EnforceLinkFlow = true;
            layout.StraightenLongLinks = true;
            layout.NodeDistance = 10;
            layout.LayerDistance = 15;
            layout.Arrange(diagram1);

            diagram1.ResizeToFitItems(5);
            diagramView1.ZoomToFit();
        }

        private void RandomGraph()
        {
            diagram1.ClearAll();

            for (int i = 0; i < 30; ++i)
            {
                int c = diagram1.Nodes.Count;
                int g = 2 + random.Next(15);
                for (int j = 0; j < g; ++j)
                {
                    ShapeNode node = diagram1.Factory.CreateShapeNode(0, 0, 40, 40);
                    node.AnchorPattern = AnchorPattern.TopInBottomOut;
                    if (j > 0)
                        diagram1.Factory.CreateDiagramLink(diagram1.Nodes[diagram1.Nodes.Count - 2], node);
                }
                if (i > 0)
                {
                    for (int j = 0; j < 1 + random.Next(3); ++j)
                        diagram1.Factory.CreateDiagramLink(
                            diagram1.Nodes[random.Next(c)],
                            diagram1.Nodes[c + random.Next(g)]);
                }
            }
        }

        Random random = new Random();
    }
}